/*
 * dummy.cpp
 *
 *  Created on: Feb 18, 2009
 *      Author: mint
 */

#include <iostream>
#include <fstream>

#include "br2.h"
#include "plinkModule.h"
#include "utils.h"

#include "dummy.h"

/*
 * Generate a dummy dataset with p individuals and s snps
 */
void DummyDataTests::generate(int p, int s)
{
    cout << "Generating dummy dataset...\n";
    srand(10);

    int i;
    int pos = locus.size();

    for (i = 0; i < s; i++) {
	Locus *a = new Locus();
	a->chr = 1;
	a->name = "snp" + toString(i);
	a->pos = 0;
	a->bp = i + 1;
	a->allele1 = 'C';
	a->allele2 = 'T';

	a->id = pos++;
	locus.push_back(a);
    }

    nlocus = locus.size();

    for (int id = 0; id < p; id++) {
	Individual *i = new Individual;

	i->iid = toString(id);
	i->fid = toString(id);
	i->pat = "0";
	i->mat = "0";
	i->sexcode = "1";
	i->phenotype = 1 + (id % 2);

	// Add necessary locus space
	i->resizeGeno(nlocus);

	for (int k = 0; k < nlocus; k++)
	    i->setGeno(k, rand() % 4);

	i->id = persons.size();
	persons.push_back(i);
    }

    npersons = persons.size();
    plinkModule p1;
    //p1.printPersons();
}

/*
 * Generate random output data.
 */
int DummyDataTests::detection(const string &infile, vector<Individual*> &Sample,
	vector<Locus*> &SNPs, int newfids, vector<ModelOutput> &out)
{
    int sig = 0;
    out.clear();
    for (int i = 0; i < SNPs.size(); i++) {
	ModelOutput a;
	a.a1 = 'C';
	a.pGeno = RNG.GetRand() / (double) RNG.GetMax();
	a.pTrend = a.pGeno;
	a.p = a.pGeno;
	a.snp = SNPs[i];

	if (a.pGeno < alpha) {
	    a.significant = 1;
	    sig++;
	} else {
	    a.significant = 0;
	}

	out.push_back(a);
    }
    cout << "DUMMY Detection.. sig= " << sig << "\n";
    return sig;
}

void DummyDataTests::estimation(const string & binfile, const string & outfile, vector<
	LogisticOutput> &results, vector<Locus*> &locus)
{
    results.clear();

    int nlocus = locus.size();

    // cout << "Dummy Estimation: size=" << nlocus << "\n";

    for (int pos = 0; pos < locus.size(); pos++) {
	double odds = 1 + (RNG.GetRand() / (double) RNG.GetMax());
	double p = (RNG.GetRand() / (double) RNG.GetMax());

	LogisticOutput r(locus[pos], 'C', odds, p);
	results.push_back(r);
    }

    cout << "DUMMY estimation.. n= " << results.size() << "\n";

}

